"""
logger4me - A simple and colorful Python logging utility

This package provides enhanced console output with ANSI color codes 
and flexible file logging options.
"""

from .logger import get_logger, ColorFormatter, LOG_COLORS

__version__ = "0.1.0"
__author__ = "the0807"
__email__ = "the0807.eom@gmail.com"
__description__ = "A simple and colorful Python logging utility"

__all__ = ["get_logger", "ColorFormatter", "LOG_COLORS"]



import logging
import os
from logging.handlers import RotatingFileHandler

# ANSI Color Code
LOG_COLORS = {
    "DEBUG": "\033[94m",     # Blue
    "INFO": "\033[92m",      # Green
    "WARNING": "\033[93m",   # Yellow
    "ERROR": "\033[91m",     # RED
    "CRITICAL": "\033[95m",  # Purple
    "RESET": "\033[0m",      # Reset
}

class ColorFormatter(logging.Formatter):
    def format(self, record):
        original_levelname = record.levelname

        padded_levelname = f"{original_levelname:<8}"
        color = LOG_COLORS.get(original_levelname, "")
        reset = LOG_COLORS["RESET"]

        record.levelname = f"{color}{padded_levelname}{reset}"
        formatted = super().format(record)

        record.levelname = original_levelname
        return formatted

def get_logger(level: int = logging.INFO, log_file: str = None, save_color: bool = False):
    logger = logging.getLogger()
    logger.setLevel(level)

    if not logger.handlers:
        datefmt = "%Y-%m-%d %H:%M:%S"

        fmt_color_str = "%(asctime)s | %(levelname)s | %(message)s"

        fmt_plain_str = "%(asctime)s | %(levelname)-8s | %(message)s"

        # Console Handler
        console_handler = logging.StreamHandler()
        console_handler.setFormatter(ColorFormatter(fmt_color_str, datefmt))
        logger.addHandler(console_handler)

        if not log_file == None:
            os.makedirs(os.path.dirname(log_file), exist_ok=True)

            # File Handler
            file_handler = logging.FileHandler(log_file, mode="w", encoding="utf-8")

            if save_color == False:
                file_handler.setFormatter(logging.Formatter(fmt_plain_str, datefmt))
            else:
                file_handler.setFormatter(ColorFormatter(fmt_color_str, datefmt))

            logger.addHandler(file_handler)

    return logger


from setuptools import setup, find_packages

setup(
    name='logger4me',
    version='0.0.2',
    description='A simple and colorful Python logging utility',
    author='the0807',
    author_email='the0807.eom@gmail.com',
    url='https://github.com/the0807/logger4me',
    license='MIT',
    packages=find_packages(exclude=[]),
    keywords = ["python", "logging", "color", "console", "utility", "ansi"],
    python_requires='>=3.6',
    package_data={},
    zip_safe=False,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Logging",
    ],
)
